# Tutorial_freMTPL2
Python tutorial for the french motor third party liability 2 dataset.

This jupyter notebook works with the scikit-learn PR https://github.com/scikit-learn/scikit-learn/pull/9405.

References:
-----------
- Datasets:
  - https://www.openml.org/d/41214
  - https://www.openml.org/d/41215

  originally from http://dutangc.free.fr/pub/RRepos/web/CASdatasets-index.html
- [Case Study: French Motor Third-Party Liability Claims](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3164764) with [R code](https://github.com/JSchelldorfer/ActuarialDataScience/tree/master/1%20-%20French%20Motor%20Third-Party%20Liability%20Claims).
